@@ -24,15 +24,17 @@ __all__ = (
     "get_version",
     "get_copyright",
     "get_license",
-    "ISOCODES_PREFIX"
+    "get_ICON_KEYBOARD",
+    "ISOCODES_PREFIX",
+    "_"
 )
 
 import gettext
 
-_ = lambda a: gettext.dgettext("ibus", a)
+_ = lambda a: gettext.dgettext("ibus10", a)
 
 def get_version():
-	return '1.3.9'
+	return '1.4.0'
 
 def get_copyright():
     return _('''Copyright (c) 2007-2010 Peng Huang
@@ -41,4 +43,12 @@ Copyright (c) 2007-2010 Red Hat, Inc.''')
 def get_license():
     return 'LGPL'
 
+def get_ICON_KEYBOARD():
+    import gtk
+    theme = gtk.icon_theme_get_default()
+    icon = 'input-keyboard-symbolic'
+    if not theme.lookup_icon(icon, 18, 0):
+        icon = 'ibus-keyboard'
+    return icon
+
 ISOCODES_PREFIX='/usr/local'
